==> ejc-zjkjcost-impl-3.0.0-20230420.081357-136-sources.jar: com/ejianc/business/zjkjcost/finish/bean/RefundEntity.java <==
package com.ejianc.business.zjkjcost.finish.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 竣工考核-对象预留奖金返还审批-主表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_finish_refund")
public class RefundEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="contract_id")
    private Long contractId; // 合同主键
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同code
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 组织code
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="department_pay_mny")
    private BigDecimal departmentPayMny; // 项目部支付清收费
    @TableField(value="department_apply_mny")
    private BigDecimal departmentApplyMny; // 项目部申请返还预留金
    @TableField(value="business_remain_mny")
    private BigDecimal businessRemainMny; // 所属单位商务管理部兑现预留金
    @TableField(value="business_actual_pay_mny")
    private BigDecimal businessActualPayMny; // 所属单位商务管理部扣除实际支付清收费
    @TableField(value="business_back_mny")
    private BigDecimal businessBackMny; // 所属单位商务管理部应返还预留金
    @TableField(value="business_actual_mny")
    private BigDecimal businessActualMny; // 所属单位商务管理部实际返还预留金
    @TableField(value="capital_actual_mny")
    private BigDecimal capitalActualMny; // 所属单位财务资金部实际支付清收费
    @TableField(value="capital_back_mny")
    private BigDecimal capitalBackMny; // 所属单位财务资金部建议返还预留金
    @TableField(value="leader_pay_mny")
    private BigDecimal leaderPayMny; //  所属单位分管领导实际支付清收费
    @TableField(value="leader_back_mny")
    private BigDecimal leaderBackMny; //  所属单位分管领导实际返还预留金
    @TableField(value="leader_actual_mny")
    private BigDecimal leaderActualMny; // 所属单位总经理实际返还预留金
    @TableField(value="chairman_actual_mny")
    private BigDecimal chairmanActualMny; // 所属单位董事长实际返还预留金

    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value = "refund_flag1")
    private  Integer refundFlag1;
    @TableField(value="refund_flag")
    private Integer refundFlag;
    @TableField(value="calculate")
    private String calculate; // 根据相关管理办法项目目标责任书，审计报告计算奖金额度
    @TableField(value="total_amount")
    private BigDecimal totalAmount; // 发放总金额
    @TableField(value="actual_mny_grant")
    private BigDecimal actualMnyGrant; // 实发金额——节点考核发放
    @TableField(value="actual_mny_out")
    private BigDecimal actualMnyOut; // 实发金额——竣工考核发放
    @TableField(value="capital_opinion")
    private String capitalOpinion; // 审批意见——所属单位财务资金部
    @TableField(value="leader_opinion")
    private String leaderOpinion; // 审批意见——所属单位分管领导
    @TableField(value="leader_actual_opinion")
    private String leaderActualOpinion; // 审批意见——所属单位总经理
    @TableField(value="chairman_opinion")
    private String chairmanOpinion; // 审批意见——所属单位董事长

    public String getCalculate() {
        return calculate;
    }

    public void setCalculate(String calculate) {
        this.calculate = calculate;
    }

    public BigDecimal getTotalAmount() {
        return totalAmount;
    }

    public void setTotalAmount(BigDecimal totalAmount) {
        this.totalAmount = totalAmount;
    }

    public BigDecimal getActualMnyGrant() {
        return actualMnyGrant;
    }

    public void setActualMnyGrant(BigDecimal actualMnyGrant) {
        this.actualMnyGrant = actualMnyGrant;
    }

    public BigDecimal getActualMnyOut() {
        return actualMnyOut;
    }

    public void setActualMnyOut(BigDecimal actualMnyOut) {
        this.actualMnyOut = actualMnyOut;
    }

    public String getCapitalOpinion() {
        return capitalOpinion;
    }

    public void setCapitalOpinion(String capitalOpinion) {
        this.capitalOpinion = capitalOpinion;
    }

    public String getLeaderOpinion() {
        return leaderOpinion;
    }

    public void setLeaderOpinion(String leaderOpinion) {
        this.leaderOpinion = leaderOpinion;
    }

    public String getLeaderActualOpinion() {
        return leaderActualOpinion;
    }

    public void setLeaderActualOpinion(String leaderActualOpinion) {
        this.leaderActualOpinion = leaderActualOpinion;
    }

    public String getChairmanOpinion() {
        return chairmanOpinion;
    }

    public void setChairmanOpinion(String chairmanOpinion) {
        this.chairmanOpinion = chairmanOpinion;
    }

    public Integer getRefundFlag() {
        return refundFlag;
    }

    public void setRefundFlag(Integer refundFlag) {
        this.refundFlag = refundFlag;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public BigDecimal getDepartmentPayMny() {
        return departmentPayMny;
    }

    public void setDepartmentPayMny(BigDecimal departmentPayMny) {
        this.departmentPayMny = departmentPayMny;
    }
    public BigDecimal getDepartmentApplyMny() {
        return departmentApplyMny;
    }

    public void setDepartmentApplyMny(BigDecimal departmentApplyMny) {
        this.departmentApplyMny = departmentApplyMny;
    }
    public BigDecimal getBusinessRemainMny() {
        return businessRemainMny;
    }

    public void setBusinessRemainMny(BigDecimal businessRemainMny) {
        this.businessRemainMny = businessRemainMny;
    }
    public BigDecimal getBusinessActualPayMny() {
        return businessActualPayMny;
    }

    public void setBusinessActualPayMny(BigDecimal businessActualPayMny) {
        this.businessActualPayMny = businessActualPayMny;
    }
    public BigDecimal getBusinessBackMny() {
        return businessBackMny;
    }

    public void setBusinessBackMny(BigDecimal businessBackMny) {
        this.businessBackMny = businessBackMny;
    }
    public BigDecimal getBusinessActualMny() {
        return businessActualMny;
    }

    public void setBusinessActualMny(BigDecimal businessActualMny) {
        this.businessActualMny = businessActualMny;
    }
    public BigDecimal getCapitalActualMny() {
        return capitalActualMny;
    }

    public void setCapitalActualMny(BigDecimal capitalActualMny) {
        this.capitalActualMny = capitalActualMny;
    }
    public BigDecimal getCapitalBackMny() {
        return capitalBackMny;
    }

    public void setCapitalBackMny(BigDecimal capitalBackMny) {
        this.capitalBackMny = capitalBackMny;
    }
    public BigDecimal getLeaderPayMny() {
        return leaderPayMny;
    }

    public void setLeaderPayMny(BigDecimal leaderPayMny) {
        this.leaderPayMny = leaderPayMny;
    }
    public BigDecimal getLeaderBackMny() {
        return leaderBackMny;
    }

    public void setLeaderBackMny(BigDecimal leaderBackMny) {
        this.leaderBackMny = leaderBackMny;
    }
    public BigDecimal getLeaderActualMny() {
        return leaderActualMny;
    }

    public void setLeaderActualMny(BigDecimal leaderActualMny) {
        this.leaderActualMny = leaderActualMny;
    }
    public BigDecimal getChairmanActualMny() {
        return chairmanActualMny;
    }

    public void setChairmanActualMny(BigDecimal chairmanActualMny) {
        this.chairmanActualMny = chairmanActualMny;
    }

    public Integer getRefundFlag1() {
        return refundFlag1;
    }

    public void setRefundFlag1(Integer refundFlag1) {
        this.refundFlag1 = refundFlag1;
    }
}

==> ejc-zjkjcost-impl-3.0.0-20230510.100923-157-sources.jar: com/ejianc/business/zjkjcost/finish/bean/RefundEntity.java <==
package com.ejianc.business.zjkjcost.finish.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 竣工考核-对象预留奖金返还审批-主表
 *
 * @author generator
 *
 */
 @TableName("ejc_zjkjcost_finish_refund")
public class RefundEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="contract_id")
    private Long contractId; // 合同主键
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="contract_code")
    private String contractCode; // 合同code
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 组织code
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织
    @TableField(value="department_pay_mny")
    private BigDecimal departmentPayMny; // 项目部支付清收费
    @TableField(value="department_apply_mny")
    private BigDecimal departmentApplyMny; // 项目部申请返还预留金
    @TableField(value="business_remain_mny")
    private BigDecimal businessRemainMny; // 所属单位商务管理部兑现预留金
    @TableField(value="business_actual_pay_mny")
    private BigDecimal businessActualPayMny; // 所属单位商务管理部扣除实际支付清收费
    @TableField(value="business_back_mny")
    private BigDecimal businessBackMny; // 所属单位商务管理部应返还预留金
    @TableField(value="business_actual_mny")
    private BigDecimal businessActualMny; // 所属单位商务管理部实际返还预留金
    @TableField(value="capital_actual_mny")
    private BigDecimal capitalActualMny; // 所属单位财务资金部实际支付清收费
    @TableField(value="capital_back_mny")
    private BigDecimal capitalBackMny; // 所属单位财务资金部建议返还预留金
    @TableField(value="leader_pay_mny")
    private BigDecimal leaderPayMny; //  所属单位分管领导实际支付清收费
    @TableField(value="leader_back_mny")
    private BigDecimal leaderBackMny; //  所属单位分管领导实际返还预留金
    @TableField(value="leader_actual_mny")
    private BigDecimal leaderActualMny; // 所属单位总经理实际返还预留金
    @TableField(value="chairman_actual_mny")
    private BigDecimal chairmanActualMny; // 所属单位董事长实际返还预留金

    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value = "refund_flag1")
    private  Integer refundFlag1;
    @TableField(value="refund_flag")
    private Integer refundFlag;
    @TableField(value="calculate")
    private String calculate; // 根据相关管理办法项目目标责任书，审计报告计算奖金额度
    @TableField(value="total_amount")
    private BigDecimal totalAmount; // 发放总金额
    @TableField(value="actual_mny_grant")
    private BigDecimal actualMnyGrant; // 实发金额——节点考核发放
    @TableField(value="actual_mny_out")
    private BigDecimal actualMnyOut; // 实发金额——竣工考核发放
    @TableField(value="capital_opinion")
    private String capitalOpinion; // 审批意见——所属单位财务资金部
    @TableField(value="leader_opinion")
    private String leaderOpinion; // 审批意见——所属单位分管领导
    @TableField(value="leader_actual_opinion")
    private String leaderActualOpinion; // 审批意见——所属单位总经理
    @TableField(value="chairman_opinion")
    private String chairmanOpinion; // 审批意见——所属单位董事长

    @TableField(value="apply_return_mny")
    private BigDecimal applyReturnMny; // 申请返还金额

    public String getCalculate() {
        return calculate;
    }

    public void setCalculate(String calculate) {
        this.calculate = calculate;
    }

    public BigDecimal getTotalAmount() {
        return totalAmount;
    }

    public void setTotalAmount(BigDecimal totalAmount) {
        this.totalAmount = totalAmount;
    }

    public BigDecimal getActualMnyGrant() {
        return actualMnyGrant;
    }

    public void setActualMnyGrant(BigDecimal actualMnyGrant) {
        this.actualMnyGrant = actualMnyGrant;
    }

    public BigDecimal getActualMnyOut() {
        return actualMnyOut;
    }

    public void setActualMnyOut(BigDecimal actualMnyOut) {
        this.actualMnyOut = actualMnyOut;
    }

    public String getCapitalOpinion() {
        return capitalOpinion;
    }

    public void setCapitalOpinion(String capitalOpinion) {
        this.capitalOpinion = capitalOpinion;
    }

    public String getLeaderOpinion() {
        return leaderOpinion;
    }

    public void setLeaderOpinion(String leaderOpinion) {
        this.leaderOpinion = leaderOpinion;
    }

    public String getLeaderActualOpinion() {
        return leaderActualOpinion;
    }

    public void setLeaderActualOpinion(String leaderActualOpinion) {
        this.leaderActualOpinion = leaderActualOpinion;
    }

    public String getChairmanOpinion() {
        return chairmanOpinion;
    }

    public void setChairmanOpinion(String chairmanOpinion) {
        this.chairmanOpinion = chairmanOpinion;
    }

    public Integer getRefundFlag() {
        return refundFlag;
    }

    public void setRefundFlag(Integer refundFlag) {
        this.refundFlag = refundFlag;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public BigDecimal getDepartmentPayMny() {
        return departmentPayMny;
    }

    public void setDepartmentPayMny(BigDecimal departmentPayMny) {
        this.departmentPayMny = departmentPayMny;
    }
    public BigDecimal getDepartmentApplyMny() {
        return departmentApplyMny;
    }

    public void setDepartmentApplyMny(BigDecimal departmentApplyMny) {
        this.departmentApplyMny = departmentApplyMny;
    }
    public BigDecimal getBusinessRemainMny() {
        return businessRemainMny;
    }

    public void setBusinessRemainMny(BigDecimal businessRemainMny) {
        this.businessRemainMny = businessRemainMny;
    }
    public BigDecimal getBusinessActualPayMny() {
        return businessActualPayMny;
    }

    public void setBusinessActualPayMny(BigDecimal businessActualPayMny) {
        this.businessActualPayMny = businessActualPayMny;
    }
    public BigDecimal getBusinessBackMny() {
        return businessBackMny;
    }

    public void setBusinessBackMny(BigDecimal businessBackMny) {
        this.businessBackMny = businessBackMny;
    }
    public BigDecimal getBusinessActualMny() {
        return businessActualMny;
    }

    public void setBusinessActualMny(BigDecimal businessActualMny) {
        this.businessActualMny = businessActualMny;
    }
    public BigDecimal getCapitalActualMny() {
        return capitalActualMny;
    }

    public void setCapitalActualMny(BigDecimal capitalActualMny) {
        this.capitalActualMny = capitalActualMny;
    }
    public BigDecimal getCapitalBackMny() {
        return capitalBackMny;
    }

    public void setCapitalBackMny(BigDecimal capitalBackMny) {
        this.capitalBackMny = capitalBackMny;
    }
    public BigDecimal getLeaderPayMny() {
        return leaderPayMny;
    }

    public void setLeaderPayMny(BigDecimal leaderPayMny) {
        this.leaderPayMny = leaderPayMny;
    }
    public BigDecimal getLeaderBackMny() {
        return leaderBackMny;
    }

    public void setLeaderBackMny(BigDecimal leaderBackMny) {
        this.leaderBackMny = leaderBackMny;
    }
    public BigDecimal getLeaderActualMny() {
        return leaderActualMny;
    }

    public void setLeaderActualMny(BigDecimal leaderActualMny) {
        this.leaderActualMny = leaderActualMny;
    }
    public BigDecimal getChairmanActualMny() {
        return chairmanActualMny;
    }

    public void setChairmanActualMny(BigDecimal chairmanActualMny) {
        this.chairmanActualMny = chairmanActualMny;
    }

    public Integer getRefundFlag1() {
        return refundFlag1;
    }

    public void setRefundFlag1(Integer refundFlag1) {
        this.refundFlag1 = refundFlag1;
    }

    public BigDecimal getApplyReturnMny() {
        return applyReturnMny;
    }

    public void setApplyReturnMny(BigDecimal applyReturnMny) {
        this.applyReturnMny = applyReturnMny;
    }
}
